==> humhub-1.8.1.tar.gz: humhub-1.8.1/protected/humhub/modules/admin/messages/lt/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '',
  '<strong>Profile</strong> Permissions' => '',
  '<strong>Settings</strong> and Configuration' => '',
  '<strong>User</strong> administration' => '',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '',
  'Accept user: <strong>{displayName}</strong> ' => 'Priimti vartotoją: <strong>{displayName}</strong> ',
  'Account' => 'Paskyra',
  'Account Request for \'{displayName}\' has been approved.' => '\'{displayName}\' paskyros prašymas patvirtintas.
',
  'Account Request for \'{displayName}\' has been declined.' => '\'{displayName}\' paskyros prašymas atmestas.',
  'Actions' => '',
  'Active users' => '',
  'Add Groups...' => '',
  'Add a separate page for the group to the directory.' => '',
  'Add new category' => 'Pridėti naują kategoriją',
  'Add new field' => 'Pridėti naują lauką',
  'Add new group' => '',
  'Add new members...' => '',
  'Add new user' => 'Pridėti naują vartotoją',
  'Administrator group could not be deleted!' => '',
  'All open registration invitations were successfully deleted.' => '',
  'All the personal data of this user will be irrevocably deleted.' => '',
  'Allow' => '',
  'Allow users to set individual permissions for their own profile?' => '',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Leisti ribotą prieigą neidentifikuotiems vartotojams (svečiams)',
  'Applied to new or existing users without any other group membership.' => '',
  'Are you really sure that you want to disable this user?' => '',
  'Are you really sure that you want to enable this user?' => '',
  'Are you really sure that you want to impersonate this user?' => '',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => '',
  'Are you sure that you want to delete following user?' => '',
  'Cancel' => 'Atšaukti',
  'Click here to review' => 'Norint peržiūrėti, spauskite čia',
  'Confirm user deletion' => '',
  'Could not load category.' => 'Nepavyko įkelti kategorijos.',
  'Create new group' => 'Sukurti naują grupę',
  'Create new profile category' => '',
  'Create new profile field' => '',
  'Deactivate' => '',
  'Deactivate individual profile permissions?' => '',
  'Decline & delete user: <strong>{displayName}</strong>' => 'Atmesti ir ištrinti vartotoją: <strong>{displayName}</strong>',
  'Default' => '',
  'Default Profile Permissions' => '',
  'Default content of the registration approval email' => '',
  'Default content of the registration denial email' => '',
  'Default groups can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Numatytasis vartotojo veiklos laiko pasibaigimas, automatinis atsijungimas (sekundėmis, kitoks)',
  'Default user profile visibility' => 'Numatytasis vartotojo profilio matymas',
  'Delete' => 'Ištrinti',
  'Delete All' => '',
  'Delete all contributions of this user' => '',
  'Delete invitation' => '',
  'Delete invitation?' => '',
  'Delete spaces which are owned by this user' => '',
  'Deleted invitation' => '',
  'Deleted users' => '',
  'Disable' => 'Išjungti',
  'Disabled' => 'Išjungtas',
  'Disabled users' => '',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => '',
  'Edit category' => '',
  'Edit profile category' => '',
  'Edit profile field' => '',
  'Edit user: {name}' => '',
  'Enable' => 'Įgalinti',
  'Enable individual profile permissions' => '',
  'Enabled' => 'Leidžiamas',
  'Group Manager' => '',
  'Group not found!' => 'Grupė nerasta!',
  'Group user not found!' => '',
  'Groups' => 'Grupės',
  'Hello {displayName},<br><br>
Your account has been activated.<br><br>
Click here to login:<br>
{loginLink}<br><br>

Kind Regards<br>
{AdminName}<br><br>' => '',
  'Hello {displayName},<br><br>
Your account request has been declined.<br><br>

Kind Regards<br>
{AdminName} <br><br> ' => '',
  'Here you can create or edit profile categories and fields.' => '',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => '',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => '',
  'Impersonate' => '',
  'Include captcha in registration form' => '',
  'Invite not found!' => '',
  'Last login' => '',
  'List pending registrations' => '',
  'Make the group selectable at registration.' => '',
  'Manage group: {groupName}' => '',
  'Manage groups' => '',
  'Manage profile attributes' => '',
  'Member since' => '',
  'Members' => 'Nariai',
  'Members can invite external users by email' => 'Nariai elektroniniu paštu gali kviesti išorinius vartotojus',
  'Message' => 'Žinutė',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'Minimali vertė yra 20 sekundžių. Jei nenustatyta, sesija baigsis po 1400 sekundžių (24 minučių) nepaisant veiksmo (numatytoji sesijos laiko baigtis)',
  'New approval requests' => 'Nauji prašymai, reikalaujantys patvirtinimo',
  'New users can register' => 'Gali registruotis anoniminiai vartotojai',
  'No' => 'Ne',
  'No value found!' => '',
  'One or more user needs your approval as group admin.' => 'Vienam ar keliems vartotojams reikalingas Jūsų, kaip grupės administratoriaus, patvirtinimas.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'Taikomas tik tada, kai limituotas priėjimas neatpažintiems vartotojams yra įjungtas. Tai liečia tik naujus vartotojus.',
  'Overview' => 'Peržiūra',
  'Password' => 'Slaptažodis',
  'Pending approvals' => '',
  'Pending user approvals' => '',
  'Permanently delete' => '',
  'Permissions' => '',
  'Profile Permissions' => '',
  'Profiles' => '',
  'Remove from group' => '',
  'Require group admin approval after registration' => 'Reikalingas grupės administratoriaus patvirtinimas po registracijos',
  'Resend invitation email' => '',
  'Save' => 'Išsaugoti',
  'Search by name, email or id.' => '',
  'Select Groups' => '',
  'Send & save' => 'Išsiųsti ir išsaugoti',
  'Send invitation email' => '',
  'Send invitation email again?' => '',
  'Send invite' => '',
  'Send notifications to users when added to or removed from the group.' => '',
  'Settings' => 'Nustatymai',
  'Show group selection at registration' => '',
  'Subject' => 'Tema',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => '',
  'The following list contains all pending sign-ups and invites.' => '',
  'The following list contains all registered users awaiting an approval.' => '',
  'The selected invitations have been successfully deleted!' => '',
  'The user is the owner of these spaces:' => '',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => '',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => '',
  'This user owns no spaces.' => '',
  'Unapproved' => 'Nepatvirtintas',
  'User deletion process queued.' => '',
  'User is already a member of this group.' => '',
  'User not found!' => 'Vartotojas nerastas!',
  'Users' => 'Vartotojai',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => '',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => '',
  'View profile' => '',
  'Visible for members only' => '',
  'Visible for members+guests' => '',
  'Yes' => 'Taip',
  'You can only delete empty categories!' => 'Galite tik ištrinti tuščias kategorijas!',
  'You cannot delete yourself!' => 'Jūs negalite ištrinti saves!',
  'never' => '',
);

==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/admin/messages/lt/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '',
  '<strong>Profile</strong> Permissions' => '',
  '<strong>Settings</strong> and Configuration' => '',
  '<strong>User</strong> administration' => '',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '',
  'Accept user: <strong>{displayName}</strong> ' => 'Priimti vartotoją: <strong>{displayName}</strong> ',
  'Account' => 'Paskyra',
  'Account Request for \'{displayName}\' has been approved.' => '\'{displayName}\' paskyros prašymas patvirtintas.
',
  'Account Request for \'{displayName}\' has been declined.' => '\'{displayName}\' paskyros prašymas atmestas.',
  'Actions' => '',
  'Active users' => '',
  'Add Groups...' => '',
  'Add new category' => 'Pridėti naują kategoriją',
  'Add new field' => 'Pridėti naują lauką',
  'Add new group' => '',
  'Add new members...' => '',
  'Add new user' => 'Pridėti naują vartotoją',
  'Administrator group could not be deleted!' => '',
  'All open registration invitations were successfully deleted.' => '',
  'All the personal data of this user will be irrevocably deleted.' => '',
  'Allow' => '',
  'Allow users to block each other' => '',
  'Allow users to set individual permissions for their own profile?' => '',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Leisti ribotą prieigą neidentifikuotiems vartotojams (svečiams)',
  'Applied to new or existing users without any other group membership.' => '',
  'Are you really sure that you want to disable this user?' => '',
  'Are you really sure that you want to enable this user?' => '',
  'Are you really sure that you want to impersonate this user?' => '',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => '',
  'Are you sure that you want to delete following user?' => '',
  'Cancel' => 'Atšaukti',
  'Click here to review' => 'Norint peržiūrėti, spauskite čia',
  'Confirm user deletion' => '',
  'Could not load category.' => 'Nepavyko įkelti kategorijos.',
  'Create new group' => 'Sukurti naują grupę',
  'Create new profile category' => '',
  'Create new profile field' => '',
  'Deactivate' => '',
  'Deactivate individual profile permissions?' => '',
  'Decline & delete user: <strong>{displayName}</strong>' => 'Atmesti ir ištrinti vartotoją: <strong>{displayName}</strong>',
  'Default' => '',
  'Default Profile Permissions' => '',
  'Default Sorting' => '',
  'Default content of the registration approval email' => '',
  'Default content of the registration denial email' => '',
  'Default group can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Numatytasis vartotojo veiklos laiko pasibaigimas, automatinis atsijungimas (sekundėmis, kitoks)',
  'Default user profile visibility' => 'Numatytasis vartotojo profilio matymas',
  'Delete' => 'Ištrinti',
  'Delete All' => '',
  'Delete all contributions of this user' => '',
  'Delete invitation' => '',
  'Delete invitation?' => '',
  'Delete spaces which are owned by this user' => '',
  'Deleted invitation' => '',
  'Deleted users' => '',
  'Disable' => 'Išjungti',
  'Disabled' => 'Išjungtas',
  'Disabled users' => '',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => '',
  'Edit category' => '',
  'Edit profile category' => '',
  'Edit profile field' => '',
  'Edit user: {name}' => '',
  'Enable' => 'Įgalinti',
  'Enable individual profile permissions' => '',
  'Enabled' => 'Leidžiamas',
  'First name' => 'Vardas',
  'Group Manager' => '',
  'Group not found!' => 'Grupė nerasta!',
  'Group user not found!' => '',
  'Groups' => 'Grupės',
  'Hello {displayName},

Your account has been activated.

Click here to login:
{loginUrl}

Kind Regards
{AdminName}

' => '',
  'Hello {displayName},

Your account request has been declined.

Kind Regards
{AdminName}

' => '',
  'Here you can create or edit profile categories and fields.' => '',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => '',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => '',
  'Impersonate' => '',
  'Include captcha in registration form' => '',
  'Information 1' => '',
  'Information 2' => '',
  'Information 3' => '',
  'Invite not found!' => '',
  'Last login' => '',
  'Last name' => 'Pavardė',
  'List pending registrations' => '',
  'Make the group selectable at registration.' => '',
  'Manage group: {groupName}' => '',
  'Manage groups' => '',
  'Manage profile attributes' => '',
  'Member since' => '',
  'Members' => 'Nariai',
  'Members can invite external users by email' => 'Nariai elektroniniu paštu gali kviesti išorinius vartotojus',
  'Message' => 'Žinutė',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'Minimali vertė yra 20 sekundžių. Jei nenustatyta, sesija baigsis po 1400 sekundžių (24 minučių) nepaisant veiksmo (numatytoji sesijos laiko baigtis)',
  'New approval requests' => 'Nauji prašymai, reikalaujantys patvirtinimo',
  'New users can register' => 'Gali registruotis anoniminiai vartotojai',
  'No' => 'Ne',
  'No value found!' => '',
  'None' => '',
  'Not visible' => '',
  'One or more user needs your approval as group admin.' => 'Vienam ar keliems vartotojams reikalingas Jūsų, kaip grupės administratoriaus, patvirtinimas.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'Taikomas tik tada, kai limituotas priėjimas neatpažintiems vartotojams yra įjungtas. Tai liečia tik naujus vartotojus.',
  'Overview' => 'Peržiūra',
  'Password' => 'Slaptažodis',
  'Pending approvals' => '',
  'Pending user approvals' => '',
  'People' => '',
  'Permanently delete' => '',
  'Permissions' => '',
  'Prioritised User Group' => '',
  'Profile Permissions' => '',
  'Profiles' => '',
  'Protected' => '',
  'Protected group can not be deleted!' => '',
  'Remove from group' => '',
  'Require group admin approval after registration' => 'Reikalingas grupės administratoriaus patvirtinimas po registracijos',
  'Resend invitation email' => '',
  'Save' => 'Išsaugoti',
  'Search by name, email or id.' => '',
  'Select Groups' => '',
  'Select a prioritised group whose members are displayed before all others when the sorting option \'Default\' is selected. The users within the group and the users outside the group are additionally sorted by their last login.' => '',
  'Select which user information should be displayed in the \'People\' overview. You can select any profile fields, even those you have created individually. ' => '',
  'Send & decline' => 'Išsiųsti ir atsisakyti',
  'Send & save' => 'Išsiųsti ir išsaugoti',
  'Send invitation email' => '',
  'Send invitation email again?' => '',
  'Send invite' => '',
  'Send notifications to users when added to or removed from the group.' => '',
  'Settings' => 'Nustatymai',
  'Show group selection at registration' => '',
  'Subject' => 'Tema',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => '',
  'The following list contains all pending sign-ups and invites.' => '',
  'The following list contains all registered users awaiting an approval.' => '',
  'The selected invitations have been successfully deleted!' => '',
  'The user is the owner of these spaces:' => '',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => '',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => '',
  'This user owns no spaces.' => '',
  'Unapproved' => 'Nepatvirtintas',
  'User deletion process queued.' => '',
  'User is already a member of this group.' => '',
  'User not found!' => 'Vartotojas nerastas!',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => '',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => '',
  'View profile' => '',
  'Visible for members only' => '',
  'Visible for members+guests' => '',
  'Will be used as a filter in \'People\'.' => '',
  'Yes' => 'Taip',
  'You can only delete empty categories!' => 'Galite tik ištrinti tuščias kategorijas!',
  'You cannot delete yourself!' => 'Jūs negalite ištrinti saves!',
  'never' => '',
);
